@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::SimClient();
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -39,6 +39,11 @@ sub suite_id {
     return $self->{suiteId};
 }
 
+sub kx_info {
+    my ($self) = @_;
+    return $self->{kxInfo};
+}
+
 1;
 __END__
 
@@ -48,7 +53,7 @@ WebService::SSLLabs::Simulation - Simulation object
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 SUBROUTINES/METHODS
 
@@ -74,6 +79,10 @@ Negotiated protocol ID.
 
 =head2 suite_id
 
+key exchange info.
+
+=head2 kx_info
+
 Negotiated suite ID.
 
 =head1 DIAGNOSTICS
